import requests

from urlparse import urljoin

from django.core.files.base import ContentFile
from django.core.files.images import ImageFile
from wagtail.wagtailimages import get_image_model

Image = get_image_model()


def get_image_file(host, uuid):
    thumbor_image = get_thumbor_image_file(host, uuid)
    if thumbor_image:
        image, _ = Image.objects.get_or_create(title=uuid, defaults={
            'file': thumbor_image
        })
        return image
    return None


def get_thumbor_image_file(host, uuid):
        url = urljoin(host, 'image/%s' % uuid)
        response = requests.get(url)
        if response.status_code == 200:
            return ImageFile(ContentFile(response.content), name=uuid)
        return None



from django.conf.urls import patterns, include, url


urlpatterns = patterns(
    '',
    url(r'^api-auth/', include(
        'rest_framework.urls', namespace='rest_framework')),
    url(
        r'^repos/$',
        'molo.core.content_import.views.get_repo_summaries',
        name='get_repo_summaries'
    ),
    url(
        r'^languages/$',
        'molo.core.content_import.views.get_repo_languages',
        name='get_repo_languages'
    ),
    url(
        r'^content/',
        'molo.core.content_import.views.import_content',
        name='import_content'
    ),
    url(
        r'^validation/',
        'molo.core.content_import.views.import_validate',
        name='import_validate'
    ),
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0027_remove_commenting_fields_from_homepage'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='HomePage',
            new_name='BannerPage',
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0010_change_on_delete_behaviour'),
        ('core', '0019_add_tags_to_article'),
    ]

    operations = [
        migrations.AddField(
            model_name='articlepage',
            name='social_media_description',
            field=models.TextField(null=True, verbose_name=b'description', blank=True),
        ),
        migrations.AddField(
            model_name='articlepage',
            name='social_media_image',
            field=models.ForeignKey(related_name='+', on_delete=django.db.models.deletion.SET_NULL, verbose_name=b'Image', blank=True, to='wagtailimages.Image', null=True),
        ),
        migrations.AddField(
            model_name='articlepage',
            name='social_media_title',
            field=models.TextField(null=True, verbose_name=b'title', blank=True),
        ),
    ]



from hashlib import md5


def hash(v):
    return md5(str(v)).hexdigest()


def conj(a, b):
    res = {}
    res.update(a)
    res.update(b)
    return res


def omit_nones(d):
    return dict((k, v) for k, v in d.iteritems() if v is not None)


def schedule(task, delay=True, *a, **kw):
    if delay:
        return task.delay(*a, **kw)
    else:
        return task(*a, **kw)



from django.contrib.auth.models import Group
from django_cas_ng.backends import CASBackend
from django.contrib.auth import get_user_model
from django.contrib.auth.backends import ModelBackend
from django.core.exceptions import PermissionDenied

from molo.profiles.models import UserProfile

UserModel = get_user_model()


class MoloModelBackend(ModelBackend):

    def authenticate(
            self, request, username=None, password=None, *args, **kwargs):
        if username is None:
            username = kwargs.get(UserModel.USERNAME_FIELD)
        try:
            user = UserModel._default_manager.get_by_natural_key(username)
            UserProfile.objects.get(user=user, site=request.site)
        except UserProfile.DoesNotExist:
            raise PermissionDenied
        except UserModel.DoesNotExist:
            UserModel().set_password(password)

        return super(MoloModelBackend, self).authenticate(
            request=request, username=username, password=password, **kwargs)


class MoloCASBackend(CASBackend):

    def authenticate(self, ticket, service, request):
        user = super(
            MoloCASBackend, self).authenticate(ticket, service, request)
        if user is None:
            return None

        if 'attributes' in request.session \
            and 'has_perm' in request.session['attributes']\
                and request.session['attributes']['has_perm'] == 'True':
            if request.session['attributes']['is_admin'] == 'True':
                user.email = request.session['attributes']['email']
                user.is_staff = True
                user.is_superuser = True
                user.save()
            else:
                wagtail_login_only_group = Group.objects.filter(
                    name='Wagtail Login Only').first()
                if wagtail_login_only_group:
                    user.groups.add(wagtail_login_only_group)
                """
                TODO: Handle case where Moderator group does not exist.
                We need to log this or find ways of notifying users that
                the moderator group was removed or renamed.
                There isn't much we can do about this case though.
                """
        else:
            user.is_staff = False
            user.is_superuser = False
            user.save()
            return None

        return user



# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-10-23 12:29
from __future__ import unicode_literals

from django.db import migrations
from django.core.management.sql import emit_post_migrate_signal


class Migration(migrations.Migration):
    def add_core_permissions_to_groups(apps, schema_editor):
        db_alias = schema_editor.connection.alias
        try:
            # Django 1.9
            emit_post_migrate_signal(2, False, db_alias)
        except TypeError:
            # Django < 1.9
            try:
                # Django 1.8
                emit_post_migrate_signal(2, False, 'default', db_alias)
            except TypeError:  # Django < 1.8
                emit_post_migrate_signal([], 2, False, 'default', db_alias)

        Group = apps.get_model('auth.Group')
        Permission = apps.get_model('auth.Permission')
        GroupPagePermission = apps.get_model('wagtailcore.GroupPagePermission')
        BannerIndexPage = apps.get_model('core.BannerIndexPage')
        SectionIndexPage = apps.get_model('core.SectionIndexPage')
        FooterIndexPage = apps.get_model('core.FooterIndexPage')

        if Group.objects.all().filter(name='Writer and Content Loader'):
            Group.objects.get(name='Writer and Content Loader').delete()

        if Group.objects.all().filter(name='Publisher'):
            Group.objects.get(name='Publisher').delete()

        # Create groups
        access_admin = Permission.objects.get(codename='access_admin')

        # <- Wagtail Login Only ->
        wagtail_login_only_group, _created = Group.objects.get_or_create(
            name='Wagtail Login Only')
        wagtail_login_only_group.permissions.add(access_admin)

        # <- Editors ->
        editor_group = Group.objects.get(name='Editors')

        # Remove the existing page permissions
        editor_group.page_permissions.all().delete()

        # Add page permissions
        sections = SectionIndexPage.objects.first()
        GroupPagePermission.objects.get_or_create(
            group=editor_group,
            page=sections,
            permission_type='add',
        )
        GroupPagePermission.objects.get_or_create(
            group=editor_group,
            page=sections,
            permission_type='edit',
        )

        banners = BannerIndexPage.objects.first()
        GroupPagePermission.objects.get_or_create(
            group=editor_group,
            page=banners,
            permission_type='add',
        )
        GroupPagePermission.objects.get_or_create(
            group=editor_group,
            page=banners,
            permission_type='edit',
        )

        add_sitelanguage = Permission.objects.get(codename='add_sitelanguage')
        editor_group.permissions.add(add_sitelanguage)

        # <- Moderator ->

        moderator_group = Group.objects.get(name='Moderators')

        add_sitelanguage = Permission.objects.get(codename='add_sitelanguage')
        change_sitelanguage = Permission.objects.get(
            codename='change_sitelanguage')
        change_user = Permission.objects.get(
            codename='change_user')
        moderator_group.permissions.add(add_sitelanguage, change_sitelanguage,
            change_user)

        moderator_group.page_permissions.all().delete()
        sections = SectionIndexPage.objects.first()
        GroupPagePermission.objects.get_or_create(
            group=moderator_group,
            page=sections,
            permission_type='add',
        )
        GroupPagePermission.objects.get_or_create(
            group=moderator_group,
            page=sections,
            permission_type='edit',
        )
        GroupPagePermission.objects.get_or_create(
            group=moderator_group,
            page=sections,
            permission_type='publish',
        )

        banners = BannerIndexPage.objects.first()
        GroupPagePermission.objects.get_or_create(
            group=moderator_group,
            page=banners,
            permission_type='add',
        )
        GroupPagePermission.objects.get_or_create(
            group=moderator_group,
            page=banners,
            permission_type='edit',
        )
        GroupPagePermission.objects.get_or_create(
            group=moderator_group,
            page=banners,
            permission_type='publish',
        )

        footers = FooterIndexPage.objects.first()
        GroupPagePermission.objects.get_or_create(
            group=moderator_group,
            page=footers,
            permission_type='add',
        )
        GroupPagePermission.objects.get_or_create(
            group=moderator_group,
            page=footers,
            permission_type='edit',
        )
        GroupPagePermission.objects.get_or_create(
            group=moderator_group,
            page=footers,
            permission_type='publish',
        )

    dependencies = [
        ('core', '0046_sitesettings_enable_clickable_tags'),
        ('contenttypes', '__latest__'),
        ('wagtailcore', '__latest__'),
        ('wagtailadmin', '__latest__'),
        ('wagtailusers', '__latest__'),
        ('sites', '__latest__'),
        ('auth', '__latest__'),
    ]

    operations = [
        migrations.RunPython(add_core_permissions_to_groups),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import molo.core.models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0028_merge'),
        ('core', '0032_sitesettings_ga_tag_manager'),
    ]

    operations = [
        migrations.CreateModel(
            name='BannerIndexPage',
            fields=[
                ('page_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='FooterIndexPage',
            fields=[
                ('page_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='SectionIndexPage',
            fields=[
                ('page_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('commenting_state', models.CharField(default=b'O', max_length=1, null=True, blank=True, choices=[(b'O', b'Open'), (b'C', b'Closed'), (b'D', b'Disabled'), (b'T', b'Timestamped')])),
                ('commenting_open_time', models.DateTimeField(null=True, blank=True)),
                ('commenting_close_time', models.DateTimeField(null=True, blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=(molo.core.models.CommentedPageMixin, 'wagtailcore.page'),
        ),
        migrations.RemoveField(
            model_name='main',
            name='commenting_close_time',
        ),
        migrations.RemoveField(
            model_name='main',
            name='commenting_open_time',
        ),
        migrations.RemoveField(
            model_name='main',
            name='commenting_state',
        ),
        migrations.AlterField(
            model_name='sitesettings',
            name='ga_tag_manager',
            field=models.CharField(help_text='GA Tag Manager tracking code (e.g GTM-XXX)', max_length=255, null=True, verbose_name='GA Tag Manager', blank=True),
        ),
    ]



import json

import pytest
import responses

from unittest import TestCase
from molo.core.content_import import api
from molo.core.content_import.errors import SiteResponseError
from molo.core.content_import.tests.utils import catch


@pytest.mark.django_db
class TestGetRepoSummaries(TestCase):
    @responses.activate
    def test_get_repo_summaries(self):
        responses.add(
            responses.GET,
            'https://www.foo.com:3000/bar/baz/repos.json',
            content_type='application/json',
            status=200,
            body=json.dumps([{
                'index': 'repo1',
                'slug': 'foo',
                'data': {
                    'name': 'win',
                    'title': 'Repo 1',
                    'owner': 'bar',
                    'descriptor': 'baz',
                },
            }, {
                'index': 'repo2',
                'slug': 'quux',
                'data': {
                    'name': 'corege',
                    'title': 'Repo 2',
                    'owner': 'grault',
                    'descriptor': 'garply',
                },
            }]))

        self.assertEqual(api.get_repo_summaries({
            'protocol': 'https',
            'host': 'www.foo.com', 'path': 'bar/baz',
            'port': 3000
        }), [{
            'name': 'repo1',
            'title': 'Repo 1',
        }, {
            'name': 'repo2',
            'title': 'Repo 2',
        }])

    @responses.activate
    def test_get_repo_summaries_error(self):
        responses.add(
            responses.GET,
            'https://www.foo.com:3000/bar/baz/repos.json',
            content_type='application/json',
            status=404,
            body=json.dumps([{
                'index': 'repo1',
                'slug': 'foo',
                'data': {
                    'name': 'win',
                    'title': 'Repo 1',
                    'owner': 'bar',
                    'descriptor': 'baz',
                },
            }, {
                'index': 'repo2',
                'slug': 'quux',
                'data': {
                    'name': 'corege',
                    'title': 'Repo 2',
                    'owner': 'grault',
                    'descriptor': 'garply',
                },
            }]))

        error = catch(SiteResponseError, lambda: api.get_repo_summaries({
            'protocol': 'https',
            'host': 'www.foo.com',
            'path': 'bar/baz',
            'port': 3000
        }))

        self.assertEqual(
            error.message,
            "https://www.foo.com:3000/bar/baz/repos.json responded "
            "with a 404 error")

    @responses.activate
    def test_get_repo_summaries_defaults(self):
        responses.add(
            responses.GET,
            'https://www.foo.com:80/repos.json',
            content_type='application/json',
            status=200,
            body=json.dumps([{
                'index': 'repo1',
                'slug': 'foo',
                'data': {
                    'name': 'win',
                    'title': 'Repo 1',
                    'owner': 'bar',
                    'descriptor': 'baz',
                },
            }, {
                'index': 'repo2',
                'slug': 'quux',
                'data': {
                    'name': 'corege',
                    'title': 'Repo 2',
                    'owner': 'grault',
                    'descriptor': 'garply',
                },
            }]))

        self.assertEqual(api.get_repo_summaries({
            'protocol': 'https',
            'host': 'www.foo.com',
            'path': None,
            'port': None
        }), [{
            'name': 'repo1',
            'title': 'Repo 1',
        }, {
            'name': 'repo2',
            'title': 'Repo 2',
        }])

    @responses.activate
    def test_get_repo_summaries_no_title(self):
        responses.add(
            responses.GET,
            'https://www.foo.com:3000/bar/baz/repos.json',
            content_type='application/json',
            status=200,
            body=json.dumps([{
                'index': 'repo1',
                'data': {
                    'name': 'win',
                },
            }, {
                'index': 'repo2',
            }]))

        self.assertEqual(api.get_repo_summaries({
            'protocol': 'https',
            'host': 'www.foo.com', 'path': 'bar/baz',
            'port': 3000
        }), [{
            'name': 'repo1',
            'title': 'repo1',
        }, {
            'name': 'repo2',
            'title': 'repo2',
        }])



"""
WSGI config for base {{cookiecutter.app_name}}.

It exposes the WSGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/1.6/howto/deployment/wsgi/
"""

import os
from django.core.wsgi import get_wsgi_application

os.environ.setdefault(
    "DJANGO_SETTINGS_MODULE", "{{cookiecutter.app_name}}.settings.production")

application = get_wsgi_application()



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0005_make_filter_spec_unique'),
        ('wagtailcore', '0010_change_page_owner_to_null_on_delete'),
        ('core', '0002_create_homepage'),
    ]

    operations = [
        migrations.CreateModel(
            name='ArticlePage',
            fields=[
                ('page_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('subtitle', models.TextField()),
                ('image', models.ForeignKey(related_name='+', on_delete=django.db.models.deletion.SET_NULL, blank=True, to='wagtailimages.Image', null=True)),
            ],
            options={
                'verbose_name': 'Article',
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='LanguagePage',
            fields=[
                ('page_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('code', models.CharField(max_length=255)),
            ],
            options={
                'verbose_name': 'Language',
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='Main',
            fields=[
                ('page_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='SectionPage',
            fields=[
                ('page_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('description', models.TextField()),
            ],
            options={
                'verbose_name': 'Section',
            },
            bases=('wagtailcore.page',),
        ),
    ]



import requests

from molo.core.content_import.errors import SiteResponseError


def get_summaries(url):
    # TODO handle error responses
    # TODO validate json response
    resp = requests.get(url)

    if is_error_response(resp):
        raise SiteResponseError(
            "%s responded with a %s error" % (url, resp.status_code))
    else:
        return parse_repo_summaries_response(resp.json())


def parse_repo_summaries_response(resp):
    return [parse_repo_summary(d) for d in resp]


def parse_repo_summary(d):
    index = d['index']

    return {
        'name': index,
        'title': d.get('data', {}).get('title', index)
    }


def is_error_response(resp):
    code = resp.status_code
    return 400 <= code < 600



import codecs
import os

from setuptools import setup, find_packages

HERE = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    with codecs.open(os.path.join(HERE, *parts), 'rb', 'utf-8') as f:
        return f.read()


install_requires = [
    'babel',
    'beautifulsoup4',
    'cached-property',
    'celery<4.0',
    'cookiecutter==1.0.0',
    'dj-database-url',
    'Django>=1.9,<1.10',
    'django-cas-ng==3.5.4',
    'django-el-pagination==3.1.0',
    'django-extensions',
    'django-google-analytics-app==2.1.4',
    'django-libsass',
    'django-mptt==0.8.5',
    'djangorestframework==3.3.2',
    'elastic-git',
    'markdown',
    'molo.profiles<6.0.0,>=5.0.0',
    'mote-prk==0.3.1',
    'raven==5.0.0',
    'redis',
    'requests',
    'setuptools>=18.5',
    'six>=1.9',
    'ujson==1.35',
    'unicore.content',
    'wagtail>=1.9,<1.10',
    'wagtailmedia==0.1.3',
]

setup(name='molo.core',
      version=read('VERSION'),
      description=('Molo is a set of tools for publishing mobi sites with a '
                   'community focus.'),
      long_description=read('README.rst'),
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Web Environment',
          'Framework :: Django',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: BSD License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Topic :: Internet :: WWW/HTTP',
          'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
      ],
      author='Praekelt.org',
      author_email='dev@praekelt.org',
      url='http://github.com/praekelt/molo',
      license='BSD',
      keywords='praekelt, mobi, web, django',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      namespace_packages=['molo'],
      install_requires=install_requires,
      entry_points={
          'console_scripts': ['molo = molo.core.scripts.cli:main'],
      })



import mock
import pytest

from django.test import TestCase, override_settings
from django.core import mail

from elasticgit.tests.base import ModelBaseTest

from molo.core.tests.base import MoloTestCaseMixin
from molo.core.content_import.tests.base import ElasticGitTestMixin
from molo.core.content_import.api import schedule_validate_content
from molo.core.content_import.tests.utils import (
    fake_repos, find_repos_from_data)


@pytest.mark.django_db
class TestScheduleValidateContent(
        TestCase, ModelBaseTest, MoloTestCaseMixin, ElasticGitTestMixin):

    def setUp(self):
        self.mk_main()

    @mock.patch('molo.core.tasks.api')
    @override_settings(
        FROM_EMAIL='from@example.org',
        CONTENT_IMPORT_SUBJECT='Content Import')
    def test_validate_successful(self, api):
        repos = fake_repos('r1', 'r2')

        api.get_repos.side_effect = lambda names, **kw: (
            find_repos_from_data(repos, names))

        api.validate_content = lambda repos, *a: {
            repos: {
                'errors': [],
                'warnings': []
            }
        }[repos]

        schedule_validate_content(
            repos,
            ['en', 'fr'],
            'us3r',
            'to@example.org',
            'h0st',
            delay=False)

        self.assertEqual(len(mail.outbox), 1)
        [email] = mail.outbox
        self.assertEqual(email.subject, 'Content Import')
        self.assertEqual(email.from_email, 'from@example.org')
        self.assertEqual(email.to, ['to@example.org'])

        self.assertTrue('us3r' in email.body)
        self.assertTrue('h0st' in email.body)
        self.assertTrue('is complete' in email.body)
        self.assertFalse('Warnings' in email.body)
        self.assertFalse('Errors' in email.body)

    @mock.patch('molo.core.tasks.api')
    @override_settings(
        FROM_EMAIL='from@example.org',
        CONTENT_IMPORT_SUBJECT='Content Import')
    def test_validate_warnings(self, api):
        repos = fake_repos('r1', 'r2')

        api.get_repos.side_effect = lambda names, **kw: (
            find_repos_from_data(repos, names))

        api.validate_content = lambda *a, **kw: {
            'errors': [],
            'warnings': [{'type': 'fake_warning'}]
        }

        schedule_validate_content(
            repos,
            ['en', 'fr'],
            'us3r',
            'to@example.org',
            'h0st',
            delay=False)

        self.assertEqual(len(mail.outbox), 1)
        [email] = mail.outbox

        self.assertEqual(email.subject, 'Content Import')
        self.assertEqual(email.from_email, 'from@example.org')
        self.assertEqual(email.to, ['to@example.org'])

        self.assertTrue('us3r' in email.body)
        self.assertTrue('h0st' in email.body)
        self.assertTrue('is complete' in email.body)
        self.assertTrue('Warnings' in email.body)
        self.assertTrue('fake_warning' in email.body)
        self.assertFalse('Errors' in email.body)

    @mock.patch('molo.core.tasks.api')
    @override_settings(
        FROM_EMAIL='from@example.org',
        CONTENT_IMPORT_SUBJECT='Content Import')
    def test_validate_errors(self, api):
        repos = fake_repos('r1', 'r2')

        api.get_repos.side_effect = lambda names, **kw: (
            find_repos_from_data(repos, names))

        api.validate_content = lambda *a, **kw: {
            'errors': [{'type': 'fake_error'}],
            'warnings': []
        }

        schedule_validate_content(
            repos,
            ['en', 'fr'],
            'us3r',
            'to@example.org',
            'h0st',
            delay=False)

        self.assertEqual(len(mail.outbox), 1)
        [email] = mail.outbox

        self.assertEqual(email.subject, 'Content Import')
        self.assertEqual(email.from_email, 'from@example.org')
        self.assertEqual(email.to, ['to@example.org'])

        self.assertTrue('us3r' in email.body)
        self.assertTrue('h0st' in email.body)
        self.assertTrue('failed' in email.body)
        self.assertFalse('Warnings' in email.body)
        self.assertTrue('Errors' in email.body)
        self.assertTrue('fake_error' in email.body)

    @mock.patch('molo.core.tasks.api')
    @override_settings(
        FROM_EMAIL='from@example.org',
        CONTENT_IMPORT_SUBJECT='Content Import')
    def test_validate_errors_and_warnings(self, api):
        repos = fake_repos('r1', 'r2')

        api.get_repos.side_effect = lambda names, **kw: (
            find_repos_from_data(repos, names))

        api.validate_content = lambda *a, **kw: {
            'errors': [{'type': 'fake_error'}],
            'warnings': [{'type': 'fake_warning'}]
        }

        schedule_validate_content(
            repos,
            ['en', 'fr'],
            'us3r',
            'to@example.org',
            'h0st',
            delay=False)

        self.assertEqual(len(mail.outbox), 1)
        [email] = mail.outbox

        self.assertEqual(email.subject, 'Content Import')
        self.assertEqual(email.from_email, 'from@example.org')
        self.assertEqual(email.to, ['to@example.org'])

        self.assertTrue('us3r' in email.body)
        self.assertTrue('h0st' in email.body)
        self.assertTrue('failed' in email.body)

        self.assertTrue('Warnings' in email.body)
        self.assertTrue('fake_warning' in email.body)

        self.assertTrue('Errors' in email.body)
        self.assertTrue('fake_error' in email.body)



from django.conf.urls import patterns, include, url

from .views import (
    search, TagsListView, ReactionQuestionChoiceView,
    ReactionQuestionChoiceFeedbackView, publish)


urlpatterns = patterns(
    '',
    url(r'^search/$', search, name='search'),
    url(
        r'^locale/(?P<locale>[\w\-\_]+)/$',
        'molo.core.views.locale_set',
        name='locale_set'
    ),
    url(
        r'^health/$',
        'molo.core.views.health',
        name='health'
    ),
    url(
        r'^home-index/$',
        'molo.core.views.home_index',
        name='home_index'
    ),
    url(
        r'^section-index/$',
        'molo.core.views.section_index',
        name='section_index'
    ),
    url(
        r'^search-index/$',
        'molo.core.views.search_index',
        name='search_index'
    ),
    url(
        r'^tag-index/$',
        'molo.core.views.tag_index',
        name='tag_index'
    ),
    url(
        r'^home-more/$',
        'molo.core.views.home_more',
        name='home_more'
    ),
    url(r'^reaction/(?P<article_slug>[0-9A-Za-z_\-]+)/'
        '(?P<question_id>\d+)/vote/$',
        ReactionQuestionChoiceView.as_view(),
        name='reaction-vote'),
    url(r'^reaction/(?P<article_slug>[0-9A-Za-z_\-]+)/'
        '(?P<question_id>\d+)/(?P<choice_slug>[0-9A-Za-z_\-]+)/feedback/$',
        ReactionQuestionChoiceFeedbackView.as_view(),
        name='reaction-feedback'),
    url(r'^import/', include(
        'molo.core.content_import.urls', namespace='content_import')),
    url(
        r'^versions/$',
        'molo.core.views.versions',
        name='versions'),
    url(r'^djga/', include('google_analytics.urls')),
    url(
        r'^tags/(?P<tag_name>[\w-]+)/$',
        TagsListView.as_view(),
        name='tags_list'
    ),
    url(r'^(\d+)/publish/$', publish, name='publish'),
)



import pytest

from django.test import TestCase
from django.core.urlresolvers import reverse
from django.contrib.auth.models import Group

from molo.core.tests.base import MoloTestCaseMixin
from molo.core.models import SiteLanguageRelation, Main, Languages


@pytest.mark.django_db
class TestImportFromGit(TestCase, MoloTestCaseMixin):

    def setUp(self):
        self.mk_main()
        main = Main.objects.all().first()
        self.language_setting = Languages.objects.create(
            site_id=main.get_site().pk)
        self.english = SiteLanguageRelation.objects.create(
            language_setting=self.language_setting,
            locale='en',
            is_active=True)
        self.user = self.login()
        self.group = Group(name="Universal Core Importers")
        self.group.save()

    def test_wagtail_has_import_menu_item(self):
        response = self.client.get(reverse('import-from-git'))
        self.assertContains(
            response, 'Import content from a Universal Core site')

    def test_wagtail_has_no_import_menu_item_for_invalid_user(self):
        response = self.client.get('/admin/')
        self.assertNotContains(
            response, 'Import content')

    def test_wagtail_has_no_import_menu_item_with_lang_page(self):
        response = self.client.get('/admin/')
        self.assertNotContains(
            response, 'Import content')

    def test_wagtail_has_import_menu_item_valid_user(self):
        self.user.groups.add(self.group)
        response = self.client.get('/admin/')
        self.assertContains(
            response, 'Import content')

    def test_wagtail_has_import_menu_item_lang_page(self):
        self.user.groups.add(self.group)
        response = self.client.get('/admin/')
        self.assertContains(
            response, 'Import content')
